package info.evccit.utils;

import net.xfra.qizxopen.xquery.dm.Node;

import java.awt.Dimension;
import java.util.Vector;

public class QImageSize
{
	static char fileSeparator;
	
	static {
		char[] carr =
			System.getProperty("file.separator").toCharArray();
		fileSeparator = carr[0];
	}
	
	/**
	 * Create a Vector giving information about an image given its file name.
	 * Hands the file name to getFileDimensions( ), which returns
	 * a Dimension object.
	 * getDimensions() then creates a Vector whose first element is
	 * the full path name (with / as the file separator). The next two
	 * elements are Integers giving the file's width and height.
	 * @param fileName Complete path and file name
	 * @return A Vector containing filename, width, and height
	 */
	public static Vector getDimensions( String fileName )
    {
		Vector result = new Vector(3);
		fileName = fileName.trim();
		try
		{
			Dimension d = ImageFileDimensions.getFileDimensions( fileName );
			result.add( fileName.replace( fileSeparator, '/' ) );
			result.add( new Integer( (int) d.getWidth() ) );
			result.add( new Integer( (int) d.getHeight() ) );
		}
		catch (Exception e)
		{
			result = null;
		}
		return result;
	}

	/**
	 * Create a Vector giving information about a file given its path and file name.
	 * Append the filename to the pathName and then call getDimensions( String fileName )
	 * @param pathName Base path name for the file
	 * @param fileName File name (without path)
	 * @return A Vector containing filename, width, and height
	 */
	public static Vector getDimensions( String pathName, String fileName )
	{
		String combinedName;
		
		pathName = pathName.trim();
		fileName = fileName.trim();

		if (pathName.endsWith( String.valueOf(fileSeparator) ))
		{
			combinedName = pathName + fileName;
		}
		else
		{
			combinedName = pathName + fileSeparator + fileName;
		}

		return getDimensions( combinedName );
	}

	/**
	 * Create a Vector giving information about a file from a base path in a Node[] and fileName in a String.
	 * The base path name is the text from the first node in basePathList.
	 * Collect the text from each node in the fileNameList, and pass it with the base path
	 * to getDimensions( String pathName, string fileName ).
	 * @param basePathList An array of nodes, the first of which contains the base path
	 *	for all the files
	 * @param fileName A String containing a file name
	 * @return A Node containing one <code>&lt;imageSize&gt;</code> element
	 */
	public static Vector getDimensions( Node[] basePathList, String fileName )
	{
		String basePath = "";
		int i;
		
		if (basePathList != null && basePathList.length > 0)
		{
			basePath = basePathList[0].getStringValue();
		}

		return getDimensions( basePath, fileName );
	}

	/**
	 * Create a Vector giving information about a file or files given in a node list.
	 * Collect the text from each node in the fileNameList, and use it as an argument
	 * to getDimensions( String fileName ).
	 * @param fileNameList A list of nodes, each of whose text content is a file name
	 * @return A Vector containing one set of filename, width, and height
	 * for each of the file names in the fileNameList.
	 */
	public static Vector getDimensions( Node[] fileNameList )
	{
		Vector result = null;

		if (fileNameList != null && fileNameList.length > 0)
		{
			result = new Vector(3 * fileNameList.length);
			for (int i = 0; i < fileNameList.length; i++)
			{
				String str = fileNameList[i].getStringValue();
				result.addAll( getDimensions( str ) );
			}
		}
		return result;
	}

	/**
	 * Create a Vector giving image Information from a base path name and file list given as arrays of Node[].
	 * The base path name is the text from the first node in basePathList.
	 * Collect the text from each node in the fileNameList, and pass it with the base path
	 * to getDimensions( String pathName, string fileName ).
	 * @param basePathList A Node[] array, the first of which contains the base path
	 *	for all the files
	 * @param fileNameList A Node[] array, each of whose text content is a file name
	 * @return A Vector containing one set of filename/width/height for each
	 *	of the file names in the fileNameList.
	 */
	public static Vector getDimensions( Node[] basePathList, Node[] fileNameList )
	{
		String basePath;
		int i;
		if (basePathList != null && basePathList.length > 0)
		{
			basePath = basePathList[0].getStringValue();
		}
		else
		{
			basePath = "";
		}

		return getDimensions( basePath, fileNameList );
	}

	/**
	 * Create a Vector of image information from a base path String and fileName Node[] array.
	 * Collect the text from each node in the fileNameList, and pass it with the base path
	 * to getDimensions( String pathName, string fileName ).
	 * @param basePath A String containing the base path for all the files
	 * @param fileNameList A list of nodes, each of whose text content is a file name
	 * @return A Vector containing one filename/width/height set for each
	 *	of the file names in the fileNameList.
	 */
	public static Vector getDimensions( String basePath, Node[] fileNameList )
	{
		Vector result = null;

		if (fileNameList != null && fileNameList.length > 0)
		{
			result = new Vector(fileNameList.length * 3);
			for (int i = 0; i < fileNameList.length; i++)
			{
				String str = fileNameList[i].getStringValue();
				result.addAll( getDimensions( basePath, str ) );
			}
		}
		return result;
	}
}
