package info.evccit.utils;

import java.awt.Dimension;

import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.apache.xpath.NodeSet;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;

public class XImageSize
{
	
	static char fileSep;
	
	static {
		char[] carr =
			System.getProperty("file.separator").toCharArray();
		fileSep = carr[0];
	}

	/**
	 * Create an <code>&lt;imageSize&gt;</code> element for a file given its file name.
	 * Hands the file name to getDimensionsFrom File( ), which returns a Dimension object.
	 * getDimensions() then creates an <code>&lt;imageSize&gt;</code> element with a "fileName"
	 * attribute equal to the full path name (with / as the file separator),
	 * and width and height attributes equal to the image file's width and height.
	 * @param fileName Complete path and file name
	 * @return A node containing an <code>&lt;imageSize&gt;</code> element
	 */
	public static Node getDimensions( String fileName )
    {
	  	Document doc = DocumentHolder.m_doc;
		Element result = null;                                    
		fileName = fileName.trim();
		try
		{
			Dimension d = ImageFileDimensions.getFileDimensions( fileName );
			result = doc.createElement("imageSize");
			result.setAttribute( "fileName",
				fileName.replace( fileSep,	'/' ) );
			result.setAttribute( "width", Integer.toString((int) d.getWidth() ) );
			result.setAttribute( "height", Integer.toString((int) d.getHeight() ));
		}
		catch (Exception e)
		{
			result = null;
		}
		return result;
	}
	
	/**
	 * Create an <code>&lt;imageSize&gt;</code> element for a file given its path and file name.
	 * Append the filename to the pathName and then call getDimensions( String fileName )
	 * @param pathName Base path name for the file
	 * @param fileName File name (without path)
	 * @return A node containing an <code>&lt;ImageSize&gt;</code> element
	 */
	public static Node getDimensions( String pathName, String fileName )
	{
		String fileSeparator = System.getProperty("file.separator");
		String combinedName;
		
		pathName = pathName.trim();
		fileName = fileName.trim();

		if (pathName.endsWith( fileSeparator ))
		{
			combinedName = pathName + fileName;
		}
		else
		{
			combinedName = pathName + fileSeparator + fileName;
		}

		return getDimensions( combinedName );
	}

	/**
	 * Create <code>&lt;imageSize&gt;</code> element(s) from a base path in a NodeList and fileName in a String.
	 * The base path name is the text from the first node in basePathList.
	 * Collect the text from each node in the fileNameList, and pass it with the base path
	 * to getDimensions( String pathName, string fileName ).
	 * @param basePathList A list of nodes, the first of which contains the base path
	 *	for all the files
	 * @param fileName A String containing a file name
	 * @return A Node containing one <code>&lt;imageSize&gt;</code> element
	 */
	public static Node getDimensions( NodeList basePathList, String fileName )
	{
		String basePath = "";
		int i;
		
		if (basePathList != null && basePathList.getLength() > 0)
		{
			basePath = getNodeText( basePathList.item(0) );
		}

		return getDimensions( basePath, fileName );
	}

	/**
	 * Create <code>&lt;imageSize&gt;</code> element(s) for a file or files given in a node list.
	 * Collect the text from each node in the fileNameList, and use it as an argument
	 * to getDimensions( String fileName ).
	 * @param fileNameList A list of nodes, each of whose text content is a file name
	 * @return A set of nodes containing one <code>&lt;imageSize&gt;</code> element for each
	 *	of the file names in the fileNameList.
	 */
	public static NodeSet getDimensions( NodeList fileNameList )
	{
		NodeSet result = null;

		if (fileNameList != null && fileNameList.getLength() > 0)
		{
			result = new NodeSet();
			for (int i = 0; i < fileNameList.getLength(); i++)
			{
				String str = getNodeText( fileNameList.item(i) );
				result.addNode( getDimensions( str ) );
			}
		}
		return result;
	}

	/**
	 * Create <code>&lt;imageSize&gt;</code> element(s) from a base path name and file list given as NodeLists.
	 * The base path name is the text from the first node in basePathList.
	 * Collect the text from each node in the fileNameList, and pass it with the base path
	 * to getDimensions( String pathName, string fileName ).
	 * @param basePathList A list of nodes, the first of which contains the base path
	 *	for all the files
	 * @param fileNameList A list of nodes, each of whose text content is a file name
	 * @return A set of nodes containing one <code>&lt;imageSize&gt;</code> element for each
	 *	of the file names in the fileNameList.
	 */
	public static NodeSet getDimensions( NodeList basePathList, NodeList fileNameList )
	{
		String basePath;
		int i;
		if (basePathList != null && basePathList.getLength() > 0)
		{
			basePath = getNodeText( basePathList.item(0) );
		}
		else
		{
			basePath = "";
		}

		return getDimensions( basePath, fileNameList );
	}

	/**
	 * Create <code>&lt;imageSize&gt;</code> element(s) from a base path String and fileName NodeList.
	 * Collect the text from each node in the fileNameList, and pass it with the base path
	 * to getDimensions( String pathName, string fileName ).
	 * @param basePath A String containing the base path for all the files
	 * @param fileNameList A list of nodes, each of whose text content is a file name
	 * @return A set of nodes containing one <code>&lt;imageSize&gt;</code> element for each
	 *	of the file names in the fileNameList.
	 */
	public static NodeSet getDimensions( String basePath, NodeList fileNameList )
	{
		NodeSet result = null;

		if (fileNameList != null && fileNameList.getLength() > 0)
		{
			result = new NodeSet();
			for (int i = 0; i < fileNameList.getLength(); i++)
			{
				String str = getNodeText( fileNameList.item(i) );
				result.addNode( getDimensions( basePath, str ) );
			}
		}
		return result;
	}

	/**
	 * Collect all the text from a node and its descendants.
	 * If the node is null, return the null string.
	 * If the node is a text node, return its value.
	 * If the node is an element, recursively visit its children
	 * and collect their text content.
	 * All other types of node return the null string.
	 * @param node The node whose text content we want
	 * @return String containing the text in the node
	 */
	static String getNodeText( Node node )
	{
		String value = "";

		if (node != null)
		{
			if (node.getNodeType() == Node.TEXT_NODE)
			{
				value = node.getNodeValue();
			}
			else if (node.getNodeType() == Node.ELEMENT_NODE)
			{
				Node child = node.getFirstChild();
				value = "";
				while (child != null)
				{
					value += getNodeText( child );
					child = child.getNextSibling();
				}
			}
		}
		return value;
	}

	/**
     * Create a static document so that we can call createElement().
	 * This code is lifted directly from the ExsltStrings.java source
	 * file in the Xalan-Java code, version 2.6.0.
	 * Licensed under Apache License: http://www.apache.org/licenses/LICENSE-2.0
	 * This class is not loaded until first referenced (see Java Language
     * Specification by Gosling/Joy/Steele, section 12.4.1)
     *
     * The static members are created when this class is first referenced, as a
     * lazy initialization not needing checking against null or any
     * synchronization.
	 *
	 * This function Copyright 1999-2004 The Apache Software Foundation.
	 *
     */
    private static class DocumentHolder 
    {
        // Reuse the Document object to reduce memory usage.
        private static final Document m_doc;
        static {
            try
            {
                m_doc =DocumentBuilderFactory.newInstance().
					newDocumentBuilder().newDocument();
            }
           
            catch(ParserConfigurationException pce)
            {
                  throw new org.apache.xml.utils.
				  	WrappedRuntimeException(pce);
            }

        }
    }
}
