declare namespace imgsize = "java:info.evccit.utils.QImageSize";
declare variable $perPage as xs:integer := 4;

declare function local:make-name-list( $animalList as element()* ) as item()+
{
	for $pig at $pos in $animalList[position() mod $perPage = 1]
	let
		$n := count($animalList),
		$filename := fn:concat("animals", $pos, ".html"),
		$start := ($pos - 1) * $perPage + 1,
		$end := if ($start + $perPage > $n)
			then 
				$n
			else
				$start + $perPage - 1
	return
	(
		<li>
		{
			for $animal at $pos in $animalList[position() >= $start and
				position() <= $end]
			return (
				<a href="{$filename}#a{$start + $pos - 1}">
					{$animal/name/text()}
				</a>,
				local:series-separator( $start, $pos, $end )
			)
		}
		</li>,
		local:make-subfile( $animalList, $start, $end, $filename)
	)
};

declare function local:series-separator( $start as xs:integer,
	$pos as xs:integer, $end as xs:integer) as xs:string
{
	if (($start + $pos < $end) and ($end - $start > 1))
	then
		", "
	else if (($start + $pos = $end) and ($end - $start >= 2))
	then
		", and "
	else if (($start + $pos = $end) and ($end - $start = 1))
	then
		" and "
	else
		""
};

declare function local:make-subfile( $animalList as element()*,
	$start as xs:integer,
	$end as xs:integer,
	$filename as xs:string) as xs:string
{
	let
	 	(: calculate this once, for use in next/back links :)
		$currentPage := (($start - 1) div $perPage) + 1
	let
		$htmlPage :=
		<html>
		<head>
			<meta http-equiv="content-type"
				content="text/html; charset=utf-8" />
			<link rel="stylesheet" type="text/css" href="bdr.css" />
			<title>Animals {$start} - {$end} (Page {$currentPage})</title>
		</head>
		<body>
		<div align="left"> {(: really unnecessary :) ""}
		<a href="index.html"><img src="images/bellydraggersranch_th.gif"
			alt="Belly Draggers Ranch Banner"
			title="Belly Draggers Ranch - A Pig Rescue Organization"
			width="225" height="48" border="0"/></a>
		</div>
		<div align="center">
		<h1>Animals {$start} - {$end} (Page {$currentPage})</h1>
		</div>
		
		<table border="0">
		 {
		   local:display-animals(
			 $animalList[position() >= $start and position() <= $end], $start
			)
		 }
		</table>
		
		<table border="0" width="100%">
		<tr>
			<td width="33%">
			{
				if ($start != 1) then
					<a href="animals{$currentPage - 1}.html">&lt;&lt;
						Page {$currentPage - 1}</a>
				else
					<br />
			}
			</td>
			<td width="33%" align="center"><a
				href="pig_index.html">Index</a></td>
			<td width="33%" align="right">
			{
				if ($end != count($animalList)) then
					<a href="animals{$currentPage + 1}.html">Page 
					{$currentPage + 1} &gt;&gt;</a>
				else
					<br />
			}	
			</td>
		</tr>
		</table>
		</body>
		</html>

	let
		$outputFilename:=
		x:serialize( $htmlPage,
			<options output="{$filename}"
			indent="yes"
			method="xhtml"
			omit-xml-declaration="yes"
			doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
			doctype-system=
			"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/>)
	return
	(
		""
	)
	
};

declare function local:display-animals( $animalList as element()*,
	$start as xs:integer )
{
	for $animal at $pos in $animalList
		let
			$bigFile := concat(
			substring-before($animal/picture/file/text(), "_th.jpg"),
			".jpg"),
			
			$basePath := $animal/../image-base,
			$dimensions := imgsize:getDimensions($basePath,
				$animal/picture/file/text() )
	return
	(
		<tr valign="top" id="{concat('a', $start + $pos - 1)}">
			<td class="bottomborder rightborder" >
				<a href="{$basePath}/{$bigFile}"><img
					src="{$dimensions[1]}" 
					alt="{$animal/picture/description/node()}"
					width="{$dimensions[2]}"
					height="{$dimensions[3]}"
					title="{$animal/picture/caption/node()}"
					hspace="4" /></a><br />
		
				<h3 align="center">{$animal/name/node()}</h3>
					   
				<div><span class="subhead">Status: </span>
					{local:show-gender($animal/gender)}</div>
				<div><span class="subhead">Born: </span>
					{$animal/birth/node()}</div>
				{
					if ($animal/death) then
						<div><span class="subhead">Died: </span>
						{$animal/death/node()}</div>
					else
						""
				}
			</td>
        
			<td class="bottomborder">
				<p class="info">
					{$animal/info/node()}
			   </p>
		   </td>
       </tr>
	)

};

declare function local:show-gender( $gender as element(gender) )
{
	let $g := $gender/node()
	return
	if ($g = "M") then 
		"Male",
		if ($gender/@spay-neuter = 'yes') then " (Neutered)" else ""
	else if ($g = "F") then
		"Female",
		if ($gender/@spay-neuter = 'yes') then " (Spayed)" else ""
	else
		""
};

let $doc := fn:input()/pig-rescue
return
(
	<html>
	<head>
		<meta http-equiv="content-type"
			content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="bdr.css" />
		<title>The Pigs</title>
	</head>
	<body>
	<div align="left">
	<a href="index.html"><img src="images/bellydraggersranch_th.gif"
		alt="Belly Draggers Ranch Banner"
		title="Belly Draggers Ranch - A Pig Rescue Organization"
		width="225" height="48" border="0"/></a>
	</div>
	<div align="center">
	<h1>The Pigs At Belly Draggers Ranch</h1>
	</div>
	
	<ul>
	{
		local:make-name-list( $doc/animal )
	}
	</ul>
	
	</body>
	</html>
	)

