<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
	xmlns:img="info.evccit.utils"
    extension-element-prefixes="redirect img">
	
<xsl:output
	method="xml"
	indent="yes"
	omit-xml-declaration="yes"
	doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
	doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
	/>

<xsl:param name="perPage" select="'4'"/>

<xsl:template match="pig-rescue">
<html>
<head>
	<meta http-equiv="content-type"
		content="text/html; charset=utf-8" />
	<link rel="stylesheet" type="text/css" href="bdr.css" />
    <title>The Pigs</title>
</head>
<body>
<div align="left">
<a href="index.html"><img src="images/bellydraggersranch_th.gif"
	alt="Belly Draggers Ranch Banner"
	title="Belly Draggers Ranch - A Pig Rescue Organization"
	width="225" height="48" border="0"/></a>
</div>
<div align="center">
<h1>The Pigs At Belly Draggers Ranch</h1>
</div>

<ul>
	<xsl:apply-templates
		select="animal[position() mod $perPage = 1]"
		mode="indexList" />
</ul>

</body>
</html>
</xsl:template>

<!-- this template is in "indexList" mode; it collects every Nth
	animal for the index page -->

<xsl:template match="animal" mode="indexList">
	<xsl:variable name="start" select="(position()-1)*$perPage + 1"/>
	
	<!-- The choose figures out the right ending number.
		If the start number plus per page is greater than the total
		number of animals, then the $end variable is set to the total
		number of animals. Otherwise, $end is set to the $start plus
		$perPage -1 -->
	<xsl:variable name="end">
		<xsl:choose>
			<xsl:when test="$start + $perPage &gt;
			count(/pig-rescue/animal)">
				<xsl:value-of select="count(/pig-rescue/animal)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$start + $perPage - 1"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<!-- we have to construct the filename in a variable so that
		redirect works properly; it doesn't like curly brace
		notation -->
	<xsl:variable name="filename">animals<xsl:value-of
	   select="position()"/>.html</xsl:variable>

	<li>
		<xsl:for-each
			select="/pig-rescue/animal[position() &gt;= $start and
			position() &lt;= $end]">
			<xsl:variable name="url"><xsl:value-of
		 	select="$filename"/>#a<xsl:value-of
			select="$start+position()-1"/></xsl:variable>
			<a href="{$url}">
				<xsl:value-of select="name"/>
			</a>
			<xsl:call-template name="seriesSeparator">
				<xsl:with-param name="start" select="$start"/>
				<xsl:with-param name="end" select="$end"/>
			</xsl:call-template>
		</xsl:for-each>
	</li>
	
	<xsl:call-template name="makeSubfile">
		<xsl:with-param name="start" select="$start"/>
		<xsl:with-param name="end" select="$end"/>
		<xsl:with-param name="filename" select="$filename"/>
	</xsl:call-template>
</xsl:template>

<!-- This template is in "display" mode; it's used to
	display all the siblings of the guys we collected -->

<xsl:template match="animal" mode="display">
	<xsl:param name="start"/>
	<xsl:variable name="bigFile"
		select="concat(substring-before(picture/file,'_th.jpg'),
		'.jpg')"/>
	<xsl:variable name="basePath" select="/pig-rescue/image-base"/>
	<xsl:variable name="dimensions"
		select="img:XImageSize.getDimensions($basePath, picture/file/text())"/>
        <tr valign="top">
        <td class="bottomborder rightborder"
		  id="{concat('a',$start+position()-1)}">
        <a href="{$basePath}/{$bigFile}"><img
			src="{$dimensions/@fileName}" 
			alt="{picture/description}"
			width="{$dimensions/@width}"
			height="{$dimensions/@height}"
			title="{picture/caption}"
			hspace="4" /></a><br />

        <h3 align="center"><xsl:value-of select="name"/></h3>
               
        <div><span class="subhead">Status: </span>
			<xsl:apply-templates select="gender"/></div>
        <div><span class="subhead">Born: </span>
			<xsl:value-of select="birth"/></div>
		<xsl:if test="death">
			<div><span class="subhead">Died: </span>
				<xsl:value-of select="death"/></div>
		</xsl:if>
        </td>
        
        <td class="bottomborder">
        <p class="info">
			<xsl:apply-templates select="info"/>
       </p>
       </td>
       </tr>
</xsl:template>

<xsl:template match="gender">
<xsl:choose>
	<xsl:when test=".='M'">
		Male
		<xsl:if test="@spay-neuter='yes'"> (Neutered)</xsl:if>
	</xsl:when>
	<xsl:when test=".='F'">
		Female
		<xsl:if test="@spay-neuter='yes'"> (Spayed)</xsl:if>
	</xsl:when>
</xsl:choose>
</xsl:template>

<!-- This template lists the animal names on a page -->
<xsl:template name="seriesSeparator">
	<xsl:param name="start"/>
	<xsl:param name="end"/>
	<xsl:choose>
		<xsl:when test="($start+position() &lt; $end) and
			($end - $start &gt; 1)">
			<xsl:text>, </xsl:text>
		</xsl:when>
		<xsl:when test="($start+position() = $end) and
			($end - $start &gt;= 2)">
			<xsl:text>, and </xsl:text>
		</xsl:when>
		<xsl:when test="($start+position() = $end) and
			($end - $start = 1)">
			<xsl:text> and </xsl:text>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<!-- This template creates the subfiles.
	It needs the $start and $end parameters so that it can create
	an accurate <title> element, and it needs $filename so
	it can open up the file in the first place. -->
<xsl:template name="makeSubfile">
	<xsl:param name="start"/>
	<xsl:param name="end"/>
	<xsl:param name="filename"/>

	<!-- calculate this once, for use in next/back links -->	
	<xsl:variable name="currentPage"
		select="(($start - 1) div $perPage) + 1"/>

	<!-- use <redirect:write> to open a file for output -->
	<redirect:write select="$filename">
		<html>
		<head>
			<meta http-equiv="content-type"
				content="text/html; charset=utf-8" />
			<link rel="stylesheet" type="text/css" href="bdr.css" />
			<title>Animals
			  <xsl:value-of select="$start"/> - <xsl:value-of select="$end"/>
			  (Page <xsl:value-of select="$currentPage"/>)</title>
		</head>
		<body>
		<div align="left">
		<a href="index.html"><img src="images/bellydraggersranch_th.gif"
			alt="Belly Draggers Ranch Banner"
			title="Belly Draggers Ranch - A Pig Rescue Organization"
			width="225" height="48" border="0"/></a>
		</div>
		<div align="center">
		<h1>Animals <xsl:value-of select="$start"/> - <xsl:value-of
		select="$end"/>
			(Page <xsl:value-of select="$currentPage"/>)</h1>
		</div>
		<table border="0">
		
				<xsl:apply-templates select="self::animal | 
					following-sibling::animal[position() &lt; $perPage]"
					mode="display">
					<xsl:with-param name="start" select="$start"/>
				</xsl:apply-templates>
		</table>
		<table border="0" width="100%">
		<tr>
			<td width="33%"> <!-- "previous" link -->
				<xsl:if test="$start != 1">
					<a href="animals{$currentPage - 1}.html">&lt;&lt; Page
					<xsl:value-of select="$currentPage - 1"/></a>
				</xsl:if>
			</td>
			<td width="33%" align="center"><a
			href="pig_index.html">Index</a></td>
			<td width="33%" align="right"> <!-- "next" link -->
				<xsl:if test="$end != count(/pig-rescue/animal)">
					<a href="animals{$currentPage + 1}.html">Page
					<xsl:value-of select="$currentPage + 1"/> &gt;&gt;</a>
				</xsl:if>	
			</td>
		</tr>
		</table>
		</body>
		</html>
	</redirect:write>

</xsl:template>
</xsl:stylesheet>

